# Features extraction


<button class="tutorial-button" onclick="window.location.href='https://github.com/sensein/senselab/blob/main/tutorials/audio/features_extraction.ipynb'">Tutorial</button>


## Task Overview

This module provides the API of the `senselab` audio features extraction.

Features can be extracted using `opensmile`, `praat-parselmouth`, `torchaudio`, and `torchaudio-squim`. More details are in the functions and in the tutorial.
